package com.kernelmaft.zanbur

import kotlinx.coroutines.Dispatchers.IO
import kotlinx.coroutines.flow.firstOrNull
import kotlinx.coroutines.launch
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import androidx.lifecycle.lifecycleScope



class MainActivity : ComponentActivity () {
	override fun onCreate ( savedInstanceState : Bundle ? ) {
		super . onCreate (savedInstanceState)

		Config . groups . forEach { AppState . addGroup (it) }

		var groups by mutableStateOf ( AppState . groups )
		AppState . subscribe { groups = it }

		lifecycleScope . launch (IO) {
			val prefs = applicationContext . dataStore . data . firstOrNull ()
			if ( prefs != null ) {
				val savedSceneName = prefs [ stringPreferencesKey ("scene") ]
				if ( savedSceneName != null ) {
					val savedScene = AppState . groups [0] . scenes . find { it . name == savedSceneName }
					if ( savedScene != null ) {
						AppState . setCurrentScene ( 0 , savedScene )
					}
				}
			}
		}

		enableEdgeToEdge ()
		setContent {
			ZanburTheme {
				Scaffold { scaffoldPadding ->
					CenteringColumn ( Modifier . padding (scaffoldPadding) . fillMaxSize () ) {

						Column ( Modifier . width ( 300 . dp ) ) {
							groups . forEach { group ->
								SceneSwitcher (group) {
									AppState . setCurrentScene ( group . id , it )
									publishSceneChange ( group , it )
								}
							}
						}
					}
				}
			}
		}

		MqttClient . run (lifecycleScope)
	}

	override fun onStop () {
		super . onStop ()

		val currentScene = AppState . groups [0] . currentScene
		if ( currentScene != null ) lifecycleScope . launch (IO) {
			applicationContext . dataStore . edit {
				it [ stringPreferencesKey ("scene") ] = currentScene . name
			}
		}
	}
}
