package com.kernelmaft.zanbur

import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers.IO
import kotlinx.coroutines.launch
import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json
import MQTTClient
import mqtt.MQTTVersion
import mqtt.Subscription
import mqtt.packets.Qos.AT_MOST_ONCE
import mqtt.packets.mqtt.MQTTPublish



typealias MqttPublishHandler = ( MQTTPublish , Json ) -> Unit

object MqttClient {
	private var client : MQTTClient ? = null
	private var coroutineScope : CoroutineScope ? = null
	private val publishHandlers : MutableList <MqttPublishHandler> = mutableListOf ()

	fun run ( coroutineScope : CoroutineScope ) {
		this . coroutineScope = coroutineScope
		val json = Json { ignoreUnknownKeys = true }

		coroutineScope . launch (IO) {
			client = MQTTClient ( MQTTVersion . MQTT5 , Config . MQTT_SERVER_HOST , Config . MQTT_SERVER_PORT , null ) {
				for ( handler in publishHandlers ) handler ( it , json )
			}
			client !! . subscribe ( listOf ( Subscription ( Config . MQTT_TOPIC + "/#" ) ) )

			client !! . run ()
		}
	}

	fun addPublishHandler ( handler : MqttPublishHandler ) = publishHandlers . add (handler)

	fun publish ( topic : String , payload : UByteArray ) {
		coroutineScope !! . launch (IO) {
			client !! . publish ( false , AT_MOST_ONCE , topic , payload )
		}
	}
}
